Model package
==================

The model package builds the graph of the robot model and stores the information about the robot's kinematics and dynamics.

.. currentmodule:: adam.model

.. automodule:: adam.model.model
   :members:
   :undoc-members:
   :show-inheritance:

adam.model.tree module
----------------------

.. automodule:: adam.model.tree
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: adam.model
   :members:
   :undoc-members:
   :show-inheritance:
